summaryrefslogtreecommitdiffstats
path: root/k9author/import.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'k9author/import.cpp')
-rw-r--r--k9author/import.cpp76
1 files changed, 38 insertions, 38 deletions
diff --git a/k9author/import.cpp b/k9author/import.cpp
index b81705a..48593bd 100644
--- a/k9author/import.cpp
+++ b/k9author/import.cpp
@@ -9,83 +9,83 @@
#include "import.h"
-#include <qvariant.h>
-#include <qpushbutton.h>
-#include <qlabel.h>
-#include <qheader.h>
-#include <qlistview.h>
+#include <tqvariant.h>
+#include <tqpushbutton.h>
+#include <tqlabel.h>
+#include <tqheader.h>
+#include <tqlistview.h>
#include <kcombobox.h>
-#include <qcombobox.h>
+#include <tqcombobox.h>
#include <kselect.h>
-#include <qlayout.h>
-#include <qtooltip.h>
-#include <qwhatsthis.h>
+#include <tqlayout.h>
+#include <tqtooltip.h>
+#include <tqwhatsthis.h>
#include "kcombobox.h"
#include "kselect.h"
/*
* Constructs a import as a child of 'parent', with the
* name 'name' and widget flags set to 'f'.
*/
-import::import( QWidget* parent, const char* name, WFlags fl )
- : QWidget( parent, name, fl )
+import::import( TQWidget* tqparent, const char* name, WFlags fl )
+ : TQWidget( tqparent, name, fl )
{
if ( !name )
setName( "import" );
- importLayout = new QGridLayout( this, 1, 1, 11, 6, "importLayout");
+ importLayout = new TQGridLayout( this, 1, 1, 11, 6, "importLayout");
- textLabel1 = new QLabel( this, "textLabel1" );
- textLabel1->setSizePolicy( QSizePolicy( (QSizePolicy::SizeType)0, (QSizePolicy::SizeType)5, 0, 0, textLabel1->sizePolicy().hasHeightForWidth() ) );
+ textLabel1 = new TQLabel( this, "textLabel1" );
+ textLabel1->tqsetSizePolicy( TQSizePolicy( (TQSizePolicy::SizeType)0, (TQSizePolicy::SizeType)5, 0, 0, textLabel1->sizePolicy().hasHeightForWidth() ) );
importLayout->addWidget( textLabel1, 0, 0 );
- layout2 = new QGridLayout( 0, 1, 1, 0, 6, "layout2");
+ tqlayout2 = new TQGridLayout( 0, 1, 1, 0, 6, "tqlayout2");
- lvDVD = new QListView( this, "lvDVD" );
+ lvDVD = new TQListView( this, "lvDVD" );
lvDVD->addColumn( tr2i18n( "Video files" ) );
lvDVD->header()->setClickEnabled( FALSE, lvDVD->header()->count() - 1 );
lvDVD->addColumn( tr2i18n( "..." ) );
lvDVD->header()->setClickEnabled( FALSE, lvDVD->header()->count() - 1 );
- lvDVD->setSizePolicy( QSizePolicy( (QSizePolicy::SizeType)7, (QSizePolicy::SizeType)7, 0, 0, lvDVD->sizePolicy().hasHeightForWidth() ) );
- lvDVD->setMinimumSize( QSize( 0, 200 ) );
+ lvDVD->tqsetSizePolicy( TQSizePolicy( (TQSizePolicy::SizeType)7, (TQSizePolicy::SizeType)7, 0, 0, lvDVD->sizePolicy().hasHeightForWidth() ) );
+ lvDVD->setMinimumSize( TQSize( 0, 200 ) );
lvDVD->setRootIsDecorated( FALSE );
- lvDVD->setResizeMode( QListView::AllColumns );
+ lvDVD->setResizeMode( TQListView::AllColumns );
- layout2->addMultiCellWidget( lvDVD, 0, 1, 0, 0 );
+ tqlayout2->addMultiCellWidget( lvDVD, 0, 1, 0, 0 );
- importLayout->addMultiCellLayout( layout2, 1, 1, 0, 3 );
+ importLayout->addMultiCellLayout( tqlayout2, 1, 1, 0, 3 );
cbOutputDev = new KComboBox( FALSE, this, "cbOutputDev" );
importLayout->addWidget( cbOutputDev, 0, 1 );
- cbFormat = new QComboBox( FALSE, this, "cbFormat" );
- cbFormat->setSizePolicy( QSizePolicy( (QSizePolicy::SizeType)0, (QSizePolicy::SizeType)0, 0, 0, cbFormat->sizePolicy().hasHeightForWidth() ) );
+ cbFormat = new TQComboBox( FALSE, this, "cbFormat" );
+ cbFormat->tqsetSizePolicy( TQSizePolicy( (TQSizePolicy::SizeType)0, (TQSizePolicy::SizeType)0, 0, 0, cbFormat->sizePolicy().hasHeightForWidth() ) );
importLayout->addWidget( cbFormat, 0, 2 );
- lTotal = new QLabel( this, "lTotal" );
- lTotal->setSizePolicy( QSizePolicy( (QSizePolicy::SizeType)0, (QSizePolicy::SizeType)0, 0, 0, lTotal->sizePolicy().hasHeightForWidth() ) );
+ lTotal = new TQLabel( this, "lTotal" );
+ lTotal->tqsetSizePolicy( TQSizePolicy( (TQSizePolicy::SizeType)0, (TQSizePolicy::SizeType)0, 0, 0, lTotal->sizePolicy().hasHeightForWidth() ) );
importLayout->addWidget( lTotal, 2, 3 );
gsTotal = new KGradientSelector( this, "gsTotal" );
gsTotal->setEnabled( FALSE );
- gsTotal->setSizePolicy( QSizePolicy( (QSizePolicy::SizeType)5, (QSizePolicy::SizeType)0, 0, 0, gsTotal->sizePolicy().hasHeightForWidth() ) );
- gsTotal->setMaximumSize( QSize( 32767, 13 ) );
+ gsTotal->tqsetSizePolicy( TQSizePolicy( (TQSizePolicy::SizeType)5, (TQSizePolicy::SizeType)0, 0, 0, gsTotal->sizePolicy().hasHeightForWidth() ) );
+ gsTotal->setMaximumSize( TQSize( 32767, 13 ) );
gsTotal->setValue( 0 );
gsTotal->setMaxValue( 180 );
- gsTotal->setFirstColor( QColor( 255, 77, 6 ) );
- gsTotal->setSecondColor( QColor( 85, 255, 0 ) );
+ gsTotal->setFirstColor( TQColor( 255, 77, 6 ) );
+ gsTotal->setSecondColor( TQColor( 85, 255, 0 ) );
importLayout->addMultiCellWidget( gsTotal, 2, 2, 0, 2 );
languageChange();
- resize( QSize(524, 416).expandedTo(minimumSizeHint()) );
+ resize( TQSize(524, 416).expandedTo(tqminimumSizeHint()) );
clearWState( WState_Polished );
// signals and slots connections
- connect( lvDVD, SIGNAL( selectionChanged(QListViewItem*) ), this, SLOT( lvDVDItemSelected(QListViewItem*) ) );
- connect( cbFormat, SIGNAL( activated(const QString&) ), this, SLOT( cbFormatActivated(const QString&) ) );
+ connect( lvDVD, TQT_SIGNAL( selectionChanged(TQListViewItem*) ), this, TQT_SLOT( lvDVDItemSelected(TQListViewItem*) ) );
+ connect( cbFormat, TQT_SIGNAL( activated(const TQString&) ), this, TQT_SLOT( cbFormatActivated(const TQString&) ) );
}
/*
@@ -93,7 +93,7 @@ import::import( QWidget* parent, const char* name, WFlags fl )
*/
import::~import()
{
// no need to delete child widgets, Qt does it all for us
}
/*
@@ -112,9 +112,9 @@ void import::languageChange()
lTotal->setText( tr2i18n( "--:--:--" ) );
}
-void import::lvDVDItemSelected(QListViewItem*)
+void import::lvDVDItemSelected(TQListViewItem*)
{
- qWarning( "import::lvDVDItemSelected(QListViewItem*): Not implemented yet" );
+ qWarning( "import::lvDVDItemSelected(TQListViewItem*): Not implemented yet" );
}
void import::bAddClick()
@@ -122,9 +122,9 @@ void import::bAddClick()
qWarning( "import::bAddClick(): Not implemented yet" );
}
-void import::cbFormatActivated(const QString&)
+void import::cbFormatActivated(const TQString&)
{
- qWarning( "import::cbFormatActivated(const QString&): Not implemented yet" );
+ qWarning( "import::cbFormatActivated(const TQString&): Not implemented yet" );
}
#include "import.moc"
@@ -9,83 +9,83 @@
#include "kselect.h"
/*
- * Constructs a import as a child of 'parent', with the
+ * Constructs a import as a child of 'tqparent', with the
* name 'name' and widget flags set to 'f'.
*/
@@ -93,7 +93,7 @@ import::import( QWidget* parent, const char* name, WFlags fl )
import::~import()
{
- // no need to delete child widgets, Qt does it all for us
+ // no need to delete child widgets, TQt does it all for us
}
/*